nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Intenclr

Struct Intenclr 

#[repr(transparent)]
pub struct Intenclr(pub u32);
Interrupt Enable Clear register.

Tuple Fields

0: u32

Implementations

Source

impl Intenclr

pub const fn mstpendingclr(&self) -> bool

Master Pending interrupt clear. Writing 1 to this bit clears the corresponding bit in the INTENSET register if implemented.

pub const fn set_mstpendingclr(&mut self, val: bool)

Master Pending interrupt clear. Writing 1 to this bit clears the corresponding bit in the INTENSET register if implemented.

pub const fn mstarblossclr(&self) -> bool

Master Arbitration Loss interrupt clear.

pub const fn set_mstarblossclr(&mut self, val: bool)

Master Arbitration Loss interrupt clear.

pub const fn mstststperrclr(&self) -> bool

Master Start/Stop Error interrupt clear.

pub const fn set_mstststperrclr(&mut self, val: bool)

Master Start/Stop Error interrupt clear.

pub const fn slvpendingclr(&self) -> bool

Slave Pending interrupt clear.

pub const fn set_slvpendingclr(&mut self, val: bool)

Slave Pending interrupt clear.

pub const fn slvnotstrclr(&self) -> bool

Slave Not Stretching interrupt clear.

pub const fn set_slvnotstrclr(&mut self, val: bool)

Slave Not Stretching interrupt clear.

pub const fn slvdeselclr(&self) -> bool

Slave Deselect interrupt clear.

pub const fn set_slvdeselclr(&mut self, val: bool)

Slave Deselect interrupt clear.

pub const fn monrdyclr(&self) -> bool

Monitor data Ready interrupt clear.

pub const fn set_monrdyclr(&mut self, val: bool)

Monitor data Ready interrupt clear.

pub const fn monovclr(&self) -> bool

Monitor Overrun interrupt clear.

pub const fn set_monovclr(&mut self, val: bool)

Monitor Overrun interrupt clear.

pub const fn monidleclr(&self) -> bool

Monitor Idle interrupt clear.

pub const fn set_monidleclr(&mut self, val: bool)

Monitor Idle interrupt clear.

pub const fn eventtimeoutclr(&self) -> bool

Event time-out interrupt clear.

pub const fn set_eventtimeoutclr(&mut self, val: bool)

Event time-out interrupt clear.

pub const fn scltimeoutclr(&self) -> bool

SCL time-out interrupt clear.

pub const fn set_scltimeoutclr(&mut self, val: bool)

SCL time-out interrupt clear.