nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Mstctl

Struct Mstctl 

#[repr(transparent)]
pub struct Mstctl(pub u32);
Master control register.

Tuple Fields

0: u32

Implementations

Source

impl Mstctl

pub const fn mstcontinue(&self) -> Mstcontinue

Master Continue. This bit is write-only.

pub const fn set_mstcontinue(&mut self, val: Mstcontinue)

Master Continue. This bit is write-only.

pub const fn mststart(&self) -> Mststart

Master Start control. This bit is write-only.

pub const fn set_mststart(&mut self, val: Mststart)

Master Start control. This bit is write-only.

pub const fn mststop(&self) -> Mststop

Master Stop control. This bit is write-only.

pub const fn set_mststop(&mut self, val: Mststop)

Master Stop control. This bit is write-only.

pub const fn mstdma(&self) -> bool

Master DMA enable. Data operations of the I2C can be performed with DMA. Protocol type operations such as Start, address, Stop, and address match must always be done with software, typically via an interrupt. Address acknowledgement must also be done by software except when the I2C is configured to be HSCAPABLE (and address acknowledgement is handled entirely by hardware) or when Automatic Operation is enabled. When a DMA data transfer is complete, MSTDMA must be cleared prior to beginning the next operation, typically a Start or Stop.This bit is read/write.

pub const fn set_mstdma(&mut self, val: bool)

Master DMA enable. Data operations of the I2C can be performed with DMA. Protocol type operations such as Start, address, Stop, and address match must always be done with software, typically via an interrupt. Address acknowledgement must also be done by software except when the I2C is configured to be HSCAPABLE (and address acknowledgement is handled entirely by hardware) or when Automatic Operation is enabled. When a DMA data transfer is complete, MSTDMA must be cleared prior to beginning the next operation, typically a Start or Stop.This bit is read/write.