nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Slvadr0

Struct Slvadr0 

#[repr(transparent)]
pub struct Slvadr0(pub u32);
Slave address register.

Tuple Fields

0: u32

Implementations

Source

impl Slvadr0

pub const fn sadisable(&self) -> Slvadr0Sadisable

Slave Address n Disable.

pub const fn set_sadisable(&mut self, val: Slvadr0Sadisable)

Slave Address n Disable.

pub const fn slvadr(&self) -> u8

Slave Address. Seven bit slave address that is compared to received addresses if enabled.

pub const fn set_slvadr(&mut self, val: u8)

Slave Address. Seven bit slave address that is compared to received addresses if enabled.

pub const fn autonack(&self) -> Autonack

Automatic NACK operation. Used in conjunction with AUTOACK and AUTOMATCHREAD, allows software to ignore I2C traffic while handling previous I2C data or other operations.

pub const fn set_autonack(&mut self, val: Autonack)

Automatic NACK operation. Used in conjunction with AUTOACK and AUTOMATCHREAD, allows software to ignore I2C traffic while handling previous I2C data or other operations.