#[repr(transparent)]pub struct Slvadr1(pub u32);Expand description
Slave address register.
Tuple Fields
0: u32Implementations
Sourceimpl Slvadr1
impl Slvadr1
Sourcepub const fn sadisable(&self) -> Slvadr1Sadisable
pub const fn sadisable(&self) -> Slvadr1Sadisable
Slave Address n Disable.
Sourcepub const fn set_sadisable(&mut self, val: Slvadr1Sadisable)
pub const fn set_sadisable(&mut self, val: Slvadr1Sadisable)
Slave Address n Disable.
Sourcepub const fn slvadr(&self) -> u8
pub const fn slvadr(&self) -> u8
Slave Address. Seven bit slave address that is compared to received addresses if enabled.
Sourcepub const fn set_slvadr(&mut self, val: u8)
pub const fn set_slvadr(&mut self, val: u8)
Slave Address. Seven bit slave address that is compared to received addresses if enabled.