#[repr(transparent)]pub struct Clkdiv(pub u32);Expand description
Clock pre-divider for the entire I2C interface. This determines what time increments are used for the MSTTIME register, and controls some timing of the Slave function.
Tuple Fields
0: u32Implementations
Sourceimpl Clkdiv
impl Clkdiv
Sourcepub const fn divval(&self) -> u16
pub const fn divval(&self) -> u16
This field controls how the Flexcomm clock (FCLK) is used by the I2C functions that need an internal clock in order to operate. 0x0000 = FCLK is used directly by the I2C. 0x0001 = FCLK is divided by 2 before use. 0x0002 = FCLK is divided by 3 before use. 0xFFFF = FCLK is divided by 65,536 before use.
Sourcepub const fn set_divval(&mut self, val: u16)
pub const fn set_divval(&mut self, val: u16)
This field controls how the Flexcomm clock (FCLK) is used by the I2C functions that need an internal clock in order to operate. 0x0000 = FCLK is used directly by the I2C. 0x0001 = FCLK is divided by 2 before use. 0x0002 = FCLK is divided by 3 before use. 0xFFFF = FCLK is divided by 65,536 before use.